# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKTransformPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkFixedCenterOfRotationAffineTransformPython
else:
    import _itkFixedCenterOfRotationAffineTransformPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkFixedArrayPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.itkScalableAffineTransformPython
import itk.itkTransformBasePython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkArray2DPython
import itk.itkVariableLengthVectorPython
import itk.itkAffineTransformPython
import itk.itkMatrixOffsetTransformBasePython

def itkFixedCenterOfRotationAffineTransformD2_New():
    return itkFixedCenterOfRotationAffineTransformD2.New()

class itkFixedCenterOfRotationAffineTransformD2(itk.itkScalableAffineTransformPython.itkScalableAffineTransformD2):
    r"""Proxy of C++ itkFixedCenterOfRotationAffineTransformD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFixedCenterOfRotationAffineTransformD2_Pointer"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFixedCenterOfRotationAffineTransformD2_Pointer"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2_Clone(self)

    def SetCenterOfRotationComponent(self, cor):
        r"""
        SetCenterOfRotationComponent(self, cor)

        Parameters
        ----------
        cor: itkPointD2 const &

        """
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2_SetCenterOfRotationComponent(self, cor)

    def GetCenterOfRotationComponent(self):
        r"""GetCenterOfRotationComponent(self) -> itkPointD2"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2_GetCenterOfRotationComponent(self)

    def SetMatrixComponent(self, matrix):
        r"""
        SetMatrixComponent(self, matrix)

        Parameters
        ----------
        matrix: itkMatrixD22 const &

        """
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2_SetMatrixComponent(self, matrix)

    def GetMatrixComponent(self):
        r"""GetMatrixComponent(self) -> itkMatrixD22"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2_GetMatrixComponent(self)

    def SetOffsetComponent(self, offset):
        r"""
        SetOffsetComponent(self, offset)

        Parameters
        ----------
        offset: itkVectorD2 const &

        """
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2_SetOffsetComponent(self, offset)

    def GetOffsetComponent(self):
        r"""GetOffsetComponent(self) -> itkVectorD2"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2_GetOffsetComponent(self)
    __swig_destroy__ = _itkFixedCenterOfRotationAffineTransformPython.delete_itkFixedCenterOfRotationAffineTransformD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFixedCenterOfRotationAffineTransformD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFixedCenterOfRotationAffineTransformD2

        Create a new object of the class itkFixedCenterOfRotationAffineTransformD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFixedCenterOfRotationAffineTransformD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFixedCenterOfRotationAffineTransformD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFixedCenterOfRotationAffineTransformD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFixedCenterOfRotationAffineTransformD2 in _itkFixedCenterOfRotationAffineTransformPython:
_itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD2_swigregister(itkFixedCenterOfRotationAffineTransformD2)

def itkFixedCenterOfRotationAffineTransformD3_New():
    return itkFixedCenterOfRotationAffineTransformD3.New()

class itkFixedCenterOfRotationAffineTransformD3(itk.itkScalableAffineTransformPython.itkScalableAffineTransformD3):
    r"""Proxy of C++ itkFixedCenterOfRotationAffineTransformD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkFixedCenterOfRotationAffineTransformD3_Pointer"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkFixedCenterOfRotationAffineTransformD3_Pointer"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3_Clone(self)

    def SetCenterOfRotationComponent(self, cor):
        r"""
        SetCenterOfRotationComponent(self, cor)

        Parameters
        ----------
        cor: itkPointD3 const &

        """
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3_SetCenterOfRotationComponent(self, cor)

    def GetCenterOfRotationComponent(self):
        r"""GetCenterOfRotationComponent(self) -> itkPointD3"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3_GetCenterOfRotationComponent(self)

    def SetMatrixComponent(self, matrix):
        r"""
        SetMatrixComponent(self, matrix)

        Parameters
        ----------
        matrix: itkMatrixD33 const &

        """
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3_SetMatrixComponent(self, matrix)

    def GetMatrixComponent(self):
        r"""GetMatrixComponent(self) -> itkMatrixD33"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3_GetMatrixComponent(self)

    def SetOffsetComponent(self, offset):
        r"""
        SetOffsetComponent(self, offset)

        Parameters
        ----------
        offset: itkVectorD3 const &

        """
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3_SetOffsetComponent(self, offset)

    def GetOffsetComponent(self):
        r"""GetOffsetComponent(self) -> itkVectorD3"""
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3_GetOffsetComponent(self)
    __swig_destroy__ = _itkFixedCenterOfRotationAffineTransformPython.delete_itkFixedCenterOfRotationAffineTransformD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkFixedCenterOfRotationAffineTransformD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkFixedCenterOfRotationAffineTransformD3

        Create a new object of the class itkFixedCenterOfRotationAffineTransformD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkFixedCenterOfRotationAffineTransformD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkFixedCenterOfRotationAffineTransformD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkFixedCenterOfRotationAffineTransformD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkFixedCenterOfRotationAffineTransformD3 in _itkFixedCenterOfRotationAffineTransformPython:
_itkFixedCenterOfRotationAffineTransformPython.itkFixedCenterOfRotationAffineTransformD3_swigregister(itkFixedCenterOfRotationAffineTransformD3)

